/**
 * This file is part of the swagger-jsdoc-express distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * swagger-jsdoc-express is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * swagger-jsdoc-express is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
import * as express from 'express';
import { GenerateSwaggerV2DocumentOptions } from './generate';
import { EntryItem } from 'fast-glob/out/types/entries';
import { IPartialOptions } from 'fast-glob/out/managers/options';
/**
 * Options for 'setupSwaggerUIFromSourceFiles()'.
 */
export interface SetupSwaggerUIFromSourceFilesOptions {
    /**
     * Custom CSS for the UI.
     */
    'css'?: string;
    /**
     * The custom root / working directory.
     */
    'cwd'?: string;
    /**
     * Show debug message(s), like errors or not.
     */
    'debug'?: boolean;
    /**
     * Options for a swagger document.
     */
    'document'?: GenerateSwaggerV2DocumentOptions;
    /**
     * Custom Favicon for the UI.
     */
    'favIcon'?: string;
    /**
     * One or more file pattern. Default: all JS and TS files inside working directory
     */
    'files'?: string | string[];
    /**
     * The custom root endpoint (name). Default: '/swagger'
     */
    'root'?: string;
    /**
     * Custom file search options.
     */
    'searchOptions'?: IPartialOptions<EntryItem>;
    /**
     * Custom site title.
     */
    'title'?: string;
    /**
     * Custom (Swagger) URL.
     */
    'url'?: string;
}
/**
 * Creates (and optionally registers) an Express router for output a Swagge V2 API documentation.
 *
 * @param {SetupSwaggerUIFromSourceFilesOptions} opts The options.
 * @param {express.Express|express.Router} [app] The optional app or router, where to register.
 */
export declare function setupSwaggerUIFromSourceFiles(opts: SetupSwaggerUIFromSourceFilesOptions, app?: express.Express | express.Router): express.Router;
